@@ -3,7 +3,7 @@
   if (!interactive()) return()
   EGRET_version = utils::packageVersion("EGRET")
   packageStartupMessage("EGRET ", EGRET_version,"
-Extended Documentation: https://rconnect.usgs.gov/EGRET")
+Extended Documentation: https://doi-usgs.github.io/EGRET")
 
 }
 
@@ -26,43 +26,20 @@ Extended Documentation: https://rconnect.usgs.gov/EGRET")
 #'
 #' @name EGRET-package
 #' @docType package
-#' @importFrom utils write.table
-#' @importFrom utils read.delim
-#' @importFrom utils URLencode
-#' @importFrom utils tail
-#' @importFrom stats aggregate
-#' @importFrom stats lm
-#' @importFrom stats median
-#' @importFrom stats sd
-#' @importFrom stats reshape
-#' @importFrom stats filter
-#' @importFrom stats rnorm
-#' @importFrom stats na.omit
 #' 
-#' @importFrom graphics abline
 #' @importFrom graphics axis
-#' @importFrom graphics box
-#' @importFrom graphics boxplot
-#' @importFrom graphics contour
-#' @importFrom graphics filled.contour
-#' @importFrom graphics grconvertX
-#' @importFrom graphics grconvertY
-#' @importFrom graphics legend
 #' @importFrom graphics lines
 #' @importFrom graphics mtext
 #' @importFrom graphics par
 #' @importFrom graphics points
 #' @importFrom graphics segments
 #' @importFrom graphics title
-#' @importFrom stats predict
-#' @importFrom stats quantile
-#' @importFrom grDevices colorRampPalette
 #' @author Robert M. Hirsch \email{rhirsch@@usgs.gov}, Laura De Cicco \email{ldecicco@@usgs.gov}
 #' @references Hirsch, R.M., and De Cicco, L.A., 2014, User guide to Exploration and Graphics for RivEr Trends 
 #' (EGRET) and dataRetrieval: R packages for hydrologic data: U.S. Geological Survey Techniques and Methods book 4, 
 #' chap. A10, 94 p., \doi{10.3133/tm4A10}
-#' @keywords water-quality graphics streamflow statistics 
-NULL
+#' @keywords internal  
+"_PACKAGE"
 
 #' Example eList
 #'
@@ -85,10 +62,10 @@ NULL
 
 #' Constants included with EGRET
 #' 
-#'\itemize{
-#'  \item{fluxConst}{Flux conversion object}
-#'  \item{qConst}{Flow conversion object}
-#'  \item{monthInfo}{Month object}
+#'\tabular{ll}{
+#' fluxConst \tab Flux conversion object\cr
+#' qConst \tab Flow conversion object\cr
+#' monthInfo \tab Month object\cr
 #'}
 #'
 #'@aliases fluxConst qConst monthInfo concConst
