@@ -20,7 +20,8 @@
 #' @param printTitle logical variable if TRUE title is printed, if FALSE title is not printed (this is best for a multi-plot figure)
 #' @param plotFlowNorm logical variable if TRUE the flow normalized line is plotted, if FALSE not plotted 
 #' @param plotAnnual logical variable if TRUE annual flux points are plotted, if FALSE not plotted 
-#' @param plotGenFlux logical variable. If \code{TRUE}, annual flux points from WRTDS_K output are plotted, if \code{FALSE} not plotted 
+#' @param plotGenFlux logical variable. If \code{TRUE}, annual flux points from 
+#' \code{WRTDSKalman} output are plotted, if \code{FALSE} the generalized flux is not plotted.
 #' @param tinyPlot logical variable, if TRUE plot is designed to be plotted small, as a part of a multipart figure, default is FALSE
 #' @param cex numerical value giving the amount by which plotting symbols should be magnified
 #' @param cex.main magnification to be used for main titles relative to the current setting of cex
@@ -115,17 +116,29 @@ plotFluxHist<-function(eList, yearStart = NA, yearEnd = NA,
   
   numYears <- length(localAnnualResults$DecYear)
   
+  ##################
+  dataStart <- min(eList$Sample$DecYear, na.rm = TRUE)
+  dataStartPad <- dataStart - 0.5
+  
   if(is.na(yearStart)){
-    yearStart <- floor(min(localAnnualResults$DecYear[!is.na(localAnnualResults$FNFlux)],na.rm = TRUE))
-  }  else {
-    yearStart <- floor(yearStart)
+    yearStart <- dataStartPad
+  } else {
+    yearStart <- max(yearStart, dataStartPad)
+    
   }
   
+  dataEnd <- max(eList$Sample$DecYear, na.rm = TRUE)
+  dataEndPad <- dataEnd + 0.5
+  
   if(is.na(yearEnd)){
-    yearEnd <- ceiling(max(localAnnualResults$DecYear[!is.na(localAnnualResults$FNFlux)],na.rm = TRUE))
-  }  else {
-    yearEnd <- floor(yearEnd) + 0.99
+    yearEnd <- dataEndPad
+  } else {
+    yearEnd <- min(yearEnd, dataEndPad)
   }
+  
+  localAnnualResults <- localAnnualResults[localAnnualResults$DecYear >= yearStart &
+                                             localAnnualResults$DecYear <= yearEnd, ]
+  
   subAnnualResults <- localAnnualResults[localAnnualResults$DecYear>=yearStart & localAnnualResults$DecYear <= yearEnd,]
   
   hasFlex <- c("segmentInfo") %in% names(attributes(eList$INFO))
